Translation suggestions — Pootle 2.7.1 documentation

# Translation suggestions

Pootle has the ability to optionally allow users to provide suggestions that need to be reviewed before they are accepted into the real translation files. Who is allowed to do what, is determined by the configuration of User permissions for the project or the server.

This allows for a team to form with different roles for different team members, and makes it possible to have a more explicit review step that requires suggestions to be checked before they become the real translations. This also allows the collection of different ideas for translating a single string.

## Viewing and making suggestions

When translating, suggestions are shown inline so they’re always visible. If a user wants to view all the suggestions within a project scope, it just needs to go to the “Review” tab and click on the “View Suggestions” link. Users with rights to translate will be shown a “Review Suggestions” link and will be able to accept and reject suggestions.

Users with rights for making suggestions will see a “Suggest” button next to “Submit”. Making a suggestions is as easy as clicking the button – hey, did you expect more steps involved?

## Reviewing suggestions

In order to review suggestions, users must have privileges to translate. There are two ways for reviewing suggestions: going through all of them, or reviewing while translating.

To go through all of them, the reviewer must click on “Review Suggestions” within the “Review” tab of the project. This would guide her/him through all the suggestions available for the current view.

The second method is straightforward, since suggestions are shown throughout the translation process. Additionally, buttons for accepting and rejecting the suggestions are displayed.

While reviewing a suggestion, a coloured difference between the current translation and the suggestion is displayed. If available, the username is provided of the user that gave the suggestion.

A click on the green tick icon approves the selected suggestion while the red cross rejects the selected suggestion. A suggestion approval doesn’t imply the rejection of the remaining suggestions.